"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEventGetRecordsActionProcessor = void 0;
const quidproquo_core_1 = require("quidproquo-core");
const quidproquo_webserver_1 = require("quidproquo-webserver");
const parseMultipartFormData_1 = require("../../utils/parseMultipartFormData");
const getProcessGetRecords = (qpqConfig) => {
    const serviceName = quidproquo_core_1.qpqCoreUtils.getApplicationModuleName(qpqConfig);
    return ({ eventParams: [apiGatewayEvent, context] }) => __awaiter(void 0, void 0, void 0, function* () {
        // Initialize `path` by removing the service name prefix from `apiGatewayEvent.path`.
        // This adjustment is necessary because the API gateway routes requests to services based on
        // a base path that includes the service name. By subtracting `serviceName.length + 1` from the
        // substring method's start index, we effectively strip the leading `/<serviceName>` segment,
        // accounting for the leading slash. This ensures `path` reflects the intended resource location
        // after the service name. Defaults to '/' if `apiGatewayEvent.path` is not provided.
        const path = (apiGatewayEvent.path || '/').substring(serviceName.length + 1);
        const internalEventRecord = {
            path,
            query: Object.assign(Object.assign({}, (apiGatewayEvent.multiValueQueryStringParameters || {})), (apiGatewayEvent.queryStringParameters || {})),
            body: apiGatewayEvent.body === null ? undefined : apiGatewayEvent.body,
            headers: apiGatewayEvent.headers,
            method: apiGatewayEvent.httpMethod,
            correlation: context.awsRequestId,
            sourceIp: apiGatewayEvent.requestContext.identity.sourceIp,
            isBase64Encoded: apiGatewayEvent.isBase64Encoded,
        };
        // Transform the body if its a multipart/form-data
        if ((quidproquo_webserver_1.qpqWebServerUtils.getHeaderValue('Content-Type', apiGatewayEvent.headers) || '').startsWith('multipart/form-data') && apiGatewayEvent.body) {
            internalEventRecord.files = yield (0, parseMultipartFormData_1.parseMultipartFormData)(apiGatewayEvent);
        }
        console.log(JSON.stringify(internalEventRecord, null, 2));
        return (0, quidproquo_core_1.actionResult)([internalEventRecord]);
    });
};
const getEventGetRecordsActionProcessor = (qpqConfig) => __awaiter(void 0, void 0, void 0, function* () {
    return ({
        [quidproquo_core_1.EventActionType.GetRecords]: getProcessGetRecords(qpqConfig),
    });
});
exports.getEventGetRecordsActionProcessor = getEventGetRecordsActionProcessor;
