"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseMultipartFormData = void 0;
const busboy_1 = __importDefault(require("busboy"));
const parseMultipartFormData = (event) => new Promise((resolve, reject) => {
    const busboy = (0, busboy_1.default)({
        headers: {
            'content-type': event.headers['content-type'] || event.headers['Content-Type'],
        },
    });
    const result = {
        files: [],
        fields: {},
    };
    busboy.on('file', (name, file, info) => {
        let fileBuffer = Buffer.alloc(0);
        file.on('data', (data) => {
            fileBuffer = Buffer.concat([fileBuffer, data]); // Concatenate the new data to the existing buffer
        });
        file.on('end', () => {
            if (fileBuffer.length > 0) {
                result.files.push({
                    filename: info.filename,
                    contentType: info.mimeType,
                    encoding: info.encoding,
                    name: name,
                    content: fileBuffer,
                });
            }
        });
    });
    busboy.on('field', (name, value) => {
        result.fields[name] = value;
    });
    busboy.on('error', (error) => {
        reject(error);
    });
    busboy.on('finish', () => {
        const qpqBinaryFiles = result.files.map((f) => ({
            filename: f.filename,
            mimetype: f.contentType,
            base64Data: f.content.toString('base64'),
        }));
        resolve(qpqBinaryFiles);
    });
    busboy.write(event.body, event.isBase64Encoded ? 'base64' : 'binary');
    busboy.end();
});
exports.parseMultipartFormData = parseMultipartFormData;
