"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getKeyValueStoreUpsertActionProcessor = void 0;
const quidproquo_core_1 = require("quidproquo-core");
const awsNamingUtils_1 = require("../../../awsNamingUtils");
const dynamo_1 = require("../../../logic/dynamo");
const quidproquo_core_2 = require("quidproquo-core");
const getProcessKeyValueStoreUpsert = (qpqConfig) => {
    return ({ keyValueStoreName, item, options }) => __awaiter(void 0, void 0, void 0, function* () {
        const dynamoTableName = (0, awsNamingUtils_1.getKvsDynamoTableNameFromConfig)(keyValueStoreName, qpqConfig, 'kvs');
        const region = quidproquo_core_1.qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const storeConfig = quidproquo_core_1.qpqCoreUtils.getKeyValueStoreByName(qpqConfig, keyValueStoreName);
        if (!storeConfig) {
            return (0, quidproquo_core_1.actionResultError)(quidproquo_core_1.ErrorTypeEnum.NotFound, `Could not find key value store with name "${keyValueStoreName}"`);
        }
        const keys = [
            storeConfig.partitionKey,
            ...storeConfig.sortKeys,
            ...storeConfig.indexes.map((i) => i.partitionKey),
            ...storeConfig.indexes.filter((i) => !!i.sortKey).map((i) => i.sortKey),
        ];
        try {
            yield (0, dynamo_1.putItem)(dynamoTableName, item, keys, {
                expires: options === null || options === void 0 ? void 0 : options.ttlInSeconds,
            }, region);
            return (0, quidproquo_core_1.actionResult)(void 0);
        }
        catch (error) {
            return (0, quidproquo_core_1.actionResultErrorFromCaughtError)(error, {
                InternalServerError: () => (0, quidproquo_core_1.actionResultError)(quidproquo_core_2.KeyValueStoreUpsertErrorTypeEnum.ServiceUnavailable, 'KVS Service Unavailable'),
                ResourceNotFoundException: () => (0, quidproquo_core_1.actionResultError)(quidproquo_core_2.KeyValueStoreUpsertErrorTypeEnum.ResourceNotFound, 'KVS Resource Not Found'),
            });
        }
    });
};
const getKeyValueStoreUpsertActionProcessor = (qpqConfig) => __awaiter(void 0, void 0, void 0, function* () {
    return ({
        [quidproquo_core_1.KeyValueStoreActionType.Upsert]: getProcessKeyValueStoreUpsert(qpqConfig),
    });
});
exports.getKeyValueStoreUpsertActionProcessor = getKeyValueStoreUpsertActionProcessor;
