"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUserDirectoryRespondToAuthChallengeActionProcessor = void 0;
const quidproquo_core_1 = require("quidproquo-core");
const awsNamingUtils_1 = require("../../../awsNamingUtils");
const getExportedValue_1 = require("../../../logic/cloudformation/getExportedValue");
const respondToAuthChallengeChallenge_1 = require("../../../logic/cognito/respondToAuthChallengeChallenge");
const client_cognito_identity_provider_1 = require("@aws-sdk/client-cognito-identity-provider");
const anyAuthChallengeToCognitoAttributes = (authChallenge) => {
    switch (authChallenge.challenge) {
        case quidproquo_core_1.AuthenticateUserChallenge.NEW_PASSWORD_REQUIRED:
            return {
                NEW_PASSWORD: authChallenge.newPassword,
            };
        case quidproquo_core_1.AuthenticateUserChallenge.CUSTOM_CHALLENGE:
            return {
                ANSWER: JSON.stringify(authChallenge.challengeAnswer),
            };
        default:
            return {};
    }
};
const anyAuthChallengeToCognitoChallengeName = (authChallenge) => {
    switch (authChallenge.challenge) {
        case quidproquo_core_1.AuthenticateUserChallenge.NEW_PASSWORD_REQUIRED:
            return client_cognito_identity_provider_1.ChallengeNameType.NEW_PASSWORD_REQUIRED;
        case quidproquo_core_1.AuthenticateUserChallenge.CUSTOM_CHALLENGE:
            return client_cognito_identity_provider_1.ChallengeNameType.CUSTOM_CHALLENGE;
        default:
            throw new Error(`Unknown challenge`);
    }
};
const getProcessRespondToAuthChallenge = (qpqConfig) => {
    return ({ userDirectoryName, authChallenge }) => __awaiter(void 0, void 0, void 0, function* () {
        const region = quidproquo_core_1.qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const userPoolId = yield (0, getExportedValue_1.getExportedValue)((0, awsNamingUtils_1.getCFExportNameUserPoolIdFromConfig)(userDirectoryName, qpqConfig), region);
        const userPoolClientId = yield (0, getExportedValue_1.getExportedValue)((0, awsNamingUtils_1.getCFExportNameUserPoolClientIdFromConfig)(userDirectoryName, qpqConfig), region);
        const response = yield (0, respondToAuthChallengeChallenge_1.respondToAuthChallengeChallenge)(userPoolId, userPoolClientId, region, authChallenge.username, authChallenge.session, anyAuthChallengeToCognitoChallengeName(authChallenge), anyAuthChallengeToCognitoAttributes(authChallenge));
        return (0, quidproquo_core_1.actionResult)(response);
    });
};
const getUserDirectoryRespondToAuthChallengeActionProcessor = (qpqConfig) => __awaiter(void 0, void 0, void 0, function* () {
    return ({
        [quidproquo_core_1.UserDirectoryActionType.RespondToAuthChallenge]: getProcessRespondToAuthChallenge(qpqConfig),
    });
});
exports.getUserDirectoryRespondToAuthChallengeActionProcessor = getUserDirectoryRespondToAuthChallengeActionProcessor;
