"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWebsocketSendMessageActionProcessor = void 0;
const quidproquo_core_1 = require("quidproquo-core");
const quidproquo_webserver_1 = require("quidproquo-webserver");
const awsNamingUtils_1 = require("../../../awsNamingUtils");
const websocketSendMessage_1 = require("../../../logic/apiGateway/websocketSendMessage");
const getExportedValue_1 = require("../../../logic/cloudformation/getExportedValue");
const getProcessSendMessage = (qpqConfig) => {
    return ({ connectionId, payload, websocketApiName }) => __awaiter(void 0, void 0, void 0, function* () {
        const region = quidproquo_core_1.qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const apiId = yield (0, getExportedValue_1.getExportedValue)((0, awsNamingUtils_1.getCFExportNameWebsocketApiIdFromConfig)(websocketApiName, qpqConfig), region);
        try {
            yield (0, websocketSendMessage_1.sendMessageToWebSocketConnection)(apiId, connectionId, region, payload);
            return (0, quidproquo_core_1.actionResult)(void 0);
        }
        catch (error) {
            return (0, quidproquo_core_1.actionResultErrorFromCaughtError)(error, {
                ThrottlingException: () => (0, quidproquo_core_1.actionResultError)(quidproquo_webserver_1.WebsocketSendMessageErrorTypeEnum.Throttled, 'Rate exceeded'),
                GoneException: () => (0, quidproquo_core_1.actionResultError)(quidproquo_webserver_1.WebsocketSendMessageErrorTypeEnum.Disconnected, 'Connection no longer exists'),
            });
        }
    });
};
const getWebsocketSendMessageActionProcessor = (qpqConfig) => __awaiter(void 0, void 0, void 0, function* () {
    return ({
        [quidproquo_webserver_1.WebsocketActionType.SendMessage]: getProcessSendMessage(qpqConfig),
    });
});
exports.getWebsocketSendMessageActionProcessor = getWebsocketSendMessageActionProcessor;
