"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getQpqLambdaRuntimeForEvent = void 0;
const dynamicModuleLoaderWarmer_1 = require("./dynamicModuleLoaderWarmer");
const logger_1 = require("./logger");
const quidproquo_core_1 = require("quidproquo-core");
const getRuntimeCorrelation_1 = require("./getRuntimeCorrelation");
const getActionProcessor_1 = require("../../getActionProcessor");
const isSnsEvent = (event) => {
    if (event && typeof event === 'object') {
        const possibleSnsEvent = event;
        return possibleSnsEvent.Records && Array.isArray(possibleSnsEvent.Records);
    }
    return false;
};
const getQpqLambdaRuntimeForEvent = (runtimeType, getStorySession, getActionProcessorList, dynamicModuleLoader, qpqConfig) => {
    return (event, context) => __awaiter(void 0, void 0, void 0, function* () {
        console.log('tick: ', JSON.stringify(event, null, 2));
        const logger = (0, logger_1.getLogger)(qpqConfig);
        const resolveStory = (0, quidproquo_core_1.createRuntime)(qpqConfig, getStorySession(event), () => __awaiter(void 0, void 0, void 0, function* () {
            return (Object.assign(Object.assign({}, (yield (0, getActionProcessor_1.getAwsActionProcessors)(qpqConfig, dynamicModuleLoader))), (yield getActionProcessorList(qpqConfig, dynamicModuleLoader))));
        }), () => new Date().toISOString(), logger, (0, getRuntimeCorrelation_1.getRuntimeCorrelation)(qpqConfig), runtimeType, dynamicModuleLoader);
        const processEvent = () => __awaiter(void 0, void 0, void 0, function* () {
            const result = yield resolveStory(quidproquo_core_1.askProcessEvent, [event, context]);
            yield logger.waitToFinishWriting();
            if (result.error) {
                throw new Error(result.error.errorText);
            }
            console.log('Finished, returning: ', result.result);
            return result.result;
        });
        if (isSnsEvent(event)) {
            // Non warmer records
            const recordsNoWarm = event.Records.filter((record) => record.EventSource !== 'aws:sns' || JSON.parse(record.Sns.Message).type !== 'QpqLambdaWarmerEvent');
            // if we have found some warmers - then we need to warm the lambda
            if (recordsNoWarm.length !== event.Records.length) {
                console.log('Found SNS warmer');
                // TODO: Warm qpq things with dynamic functions
                // federate in dynamic modules
                yield (0, dynamicModuleLoaderWarmer_1.dynamicModuleLoaderWarmer)();
                // Might as well move the logs to permanent storage
                yield logger.moveToPermanentStorage();
                return 'Warmed up!';
            }
            // If we have events that are not warmers, then we should execute them
            if (recordsNoWarm.length > 0) {
                console.log('Running other actions');
                return yield processEvent();
            }
        }
        return yield processEvent();
    });
};
exports.getQpqLambdaRuntimeForEvent = getQpqLambdaRuntimeForEvent;
