"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLogger = exports.moveLogsToPerminateStorage = exports.storyLoggerFs = exports.storyLogger = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const client_s3_1 = require("@aws-sdk/client-s3");
const quidproquo_core_1 = require("quidproquo-core");
const tempDirectory = '/tmp/qpqlogs';
const quidproquo_config_aws_1 = require("quidproquo-config-aws");
const awsNamingUtils_1 = require("../../awsNamingUtils");
const storyLogger = (result, bucketName, region) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const s3Client = new client_s3_1.S3Client({ region });
        const commandParams = {
            Key: `${result.correlation}.json`,
            Bucket: bucketName,
            Body: JSON.stringify(result),
            StorageClass: 'INTELLIGENT_TIERING',
        };
        yield s3Client.send(new client_s3_1.PutObjectCommand(commandParams));
    }
    catch (_a) {
        console.log(`Failed to log story result to S3 [${result.correlation}]`);
    }
});
exports.storyLogger = storyLogger;
const storyLoggerFs = (result) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield fs_1.default.promises.mkdir(tempDirectory, { recursive: true });
        const filePath = path_1.default.join(tempDirectory, `${result.correlation}.json`);
        yield fs_1.default.promises.writeFile(filePath, JSON.stringify(result));
        console.log(`Story result logged to temporary file [${filePath}]`);
    }
    catch (error) {
        console.log(`Failed to log story result to temporary file [${result.correlation}]`);
        console.error(error);
    }
});
exports.storyLoggerFs = storyLoggerFs;
const moveLogsToPerminateStorage = (bucketName, region) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield fs_1.default.promises.mkdir(tempDirectory, { recursive: true });
        const files = yield fs_1.default.promises.readdir(tempDirectory);
        for (const file of files) {
            const filePath = path_1.default.join(tempDirectory, file);
            const data = yield fs_1.default.promises.readFile(filePath, 'utf-8');
            const result = JSON.parse(data);
            yield (0, exports.storyLogger)(result, bucketName, region);
            yield fs_1.default.promises.unlink(filePath);
            console.log(`Moved log file [${file}] to S3 and deleted from temporary directory`);
        }
    }
    catch (error) {
        console.error('Failed to move logs to permanent storage');
        console.error(error);
    }
});
exports.moveLogsToPerminateStorage = moveLogsToPerminateStorage;
const getLogger = (qpqConfig) => {
    const awsSettings = (0, quidproquo_config_aws_1.getAwsServiceAccountInfoConfig)(qpqConfig);
    // If we have no log service, just return nothing.
    if (!awsSettings.logServiceName || awsSettings.disableLogs || process.env.storageDriveName === 'qpq-logs') {
        return {
            log: () => __awaiter(void 0, void 0, void 0, function* () { }),
            waitToFinishWriting: () => __awaiter(void 0, void 0, void 0, function* () { }),
            moveToPermanentStorage: () => __awaiter(void 0, void 0, void 0, function* () { }),
        };
    }
    const service = awsSettings.logServiceName;
    const application = quidproquo_core_1.qpqCoreUtils.getApplicationName(qpqConfig);
    const environment = quidproquo_core_1.qpqCoreUtils.getApplicationModuleEnvironment(qpqConfig);
    const feature = quidproquo_core_1.qpqCoreUtils.getApplicationModuleFeature(qpqConfig);
    // Workout the bucket name.
    const bucketName = (0, awsNamingUtils_1.getConfigRuntimeResourceName)('qpq-logs', application, service, environment, feature);
    // Where is this bucket?
    const regionForBucket = (0, quidproquo_config_aws_1.getAwsServiceAccountInfoByDeploymentInfo)(qpqConfig, service, environment, feature, application).awsRegion;
    console.log('Bucket for logs: ', bucketName, regionForBucket);
    const logs = [];
    return {
        log: (result) => __awaiter(void 0, void 0, void 0, function* () {
            const promise = (0, exports.storyLogger)(result, bucketName, regionForBucket).catch((e) => {
                console.log('Failed to log story result to S3', JSON.stringify(e, null, 2));
            });
            logs.push(promise);
            console.log('Added to logs', logs.length);
        }),
        waitToFinishWriting: () => __awaiter(void 0, void 0, void 0, function* () {
            console.log('logs.length', logs.length);
            console.time('Writing Logs');
            yield Promise.all(logs);
            console.timeEnd('Writing Logs');
            console.log('done writing logs');
        }),
        moveToPermanentStorage: () => __awaiter(void 0, void 0, void 0, function* () {
            yield (0, exports.moveLogsToPerminateStorage)(bucketName, regionForBucket);
        }),
    };
};
exports.getLogger = getLogger;
