"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findMatchingCertificates = void 0;
const client_acm_1 = require("@aws-sdk/client-acm");
const createAwsClient_1 = require("../createAwsClient");
const findMatchingCertificates = (domainName, region, retryCount = 3, delayMs = 5000) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const lowerCaseDomainName = domainName.toLowerCase();
    const acmClient = (0, createAwsClient_1.createAwsClient)(client_acm_1.ACMClient, {
        region,
    });
    let remainingRetries = retryCount;
    while (remainingRetries > 0) {
        let certificateArns = [];
        let NextToken;
        do {
            const listCommand = new client_acm_1.ListCertificatesCommand({
                NextToken,
            });
            const listResult = yield acmClient.send(listCommand);
            for (const certificate of listResult.CertificateSummaryList || []) {
                if (certificate.CertificateArn &&
                    ((_a = certificate.DomainName) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === lowerCaseDomainName) {
                    certificateArns.push(certificate.CertificateArn);
                }
            }
            NextToken = listResult.NextToken;
        } while (NextToken);
        if (certificateArns.length > 0) {
            return certificateArns;
        }
        remainingRetries--;
        if (remainingRetries != 0) {
            // Don't wait after the last try
            yield new Promise((res) => setTimeout(res, delayMs));
        }
    }
    return []; // Return an empty array after max retries
});
exports.findMatchingCertificates = findMatchingCertificates;
// (async () => {
//   const matchingCerts = await findMatchingCertificates('example.com', 'us-east-1');
//   console.log('Matching certificates:', matchingCerts);
// })();
