"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDomainValidationOptions = void 0;
const client_acm_1 = require("@aws-sdk/client-acm");
const createAwsClient_1 = require("../createAwsClient");
const getDomainValidationOptions = (certificateArn, region) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b;
    const acmClient = (0, createAwsClient_1.createAwsClient)(client_acm_1.ACMClient, {
        region,
    });
    const command = new client_acm_1.DescribeCertificateCommand({
        CertificateArn: certificateArn,
    });
    const result = yield acmClient.send(command);
    const entries = {};
    console.log('DescribeCertificateCommand: ', JSON.stringify(result, null, 2));
    // Extract the DomainValidationOptions and populate the entries
    if (result.Certificate && result.Certificate.DomainValidationOptions) {
        for (const option of result.Certificate.DomainValidationOptions) {
            if (((_a = option.ResourceRecord) === null || _a === void 0 ? void 0 : _a.Name) && ((_b = option.ResourceRecord) === null || _b === void 0 ? void 0 : _b.Value)) {
                entries[option.ResourceRecord.Name] = {
                    proxied: false,
                    type: 'CNAME',
                    value: option.ResourceRecord.Value,
                };
            }
        }
    }
    return entries;
});
exports.getDomainValidationOptions = getDomainValidationOptions;
