"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createUser = void 0;
const client_cognito_identity_provider_1 = require("@aws-sdk/client-cognito-identity-provider");
const authenticateUser_1 = require("./authenticateUser");
const setUserPassword_1 = require("./setUserPassword");
const cognitoAttributeMap_1 = require("./cognitoAttributeMap");
const createAwsClient_1 = require("../createAwsClient");
const createUser = (userPoolId, region, clientId, createUserRequest) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const cognitoClient = (0, createAwsClient_1.createAwsClient)(client_cognito_identity_provider_1.CognitoIdentityProviderClient, { region });
    const params = {
        UserPoolId: userPoolId,
        Username: createUserRequest.email,
        MessageAction: client_cognito_identity_provider_1.MessageActionType.SUPPRESS,
        DesiredDeliveryMediums: [client_cognito_identity_provider_1.DeliveryMediumType.EMAIL],
        UserAttributes: (0, cognitoAttributeMap_1.getCognitoUserAttributesFromQpqUserAttributes)(createUserRequest),
        ForceAliasCreation: false,
    };
    if (createUserRequest.phoneNumber) {
        params.DesiredDeliveryMediums.push(client_cognito_identity_provider_1.DeliveryMediumType.SMS);
    }
    const response = yield cognitoClient.send(new client_cognito_identity_provider_1.AdminCreateUserCommand(params));
    const username = ((_a = response.User) === null || _a === void 0 ? void 0 : _a.Username) || '';
    // Set the user's password
    yield (0, setUserPassword_1.setUserPassword)(region, userPoolId, username, createUserRequest.password);
    // Authenticate the user
    const authResponse = yield (0, authenticateUser_1.authenticateUser)(userPoolId, clientId, region, false, username, createUserRequest.password);
    return authResponse;
});
exports.createUser = createUser;
