"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.query = void 0;
const client_dynamodb_1 = require("@aws-sdk/client-dynamodb");
const convertObjectToDynamoMap_1 = require("./convertObjectToDynamoMap");
const logs_1 = require("./logs");
const itemsToQpqPagedData_1 = require("./utils/itemsToQpqPagedData");
const qpqDynamoOrm_1 = require("./qpqDynamoOrm");
const createAwsClient_1 = require("../createAwsClient");
function query(tableName, region, keyExpression, filterExpression, pageKey, indexName, limit, sortAscending) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        // Instantiate DynamoDB client
        const dynamoDBClient = (0, createAwsClient_1.createAwsClient)(client_dynamodb_1.DynamoDBClient, { region });
        const params = {
            TableName: tableName,
            KeyConditionExpression: (0, qpqDynamoOrm_1.buildDynamoQueryExpression)(keyExpression),
            FilterExpression: filterExpression && (0, qpqDynamoOrm_1.buildDynamoQueryExpression)(filterExpression),
            ExpressionAttributeValues: (0, qpqDynamoOrm_1.buildExpressionAttributeValues)([keyExpression, filterExpression]),
            ExpressionAttributeNames: (0, qpqDynamoOrm_1.buildExpressionAttributeNames)([keyExpression, filterExpression]),
            IndexName: indexName,
            Limit: limit,
            ScanIndexForward: sortAscending,
        };
        if (pageKey) {
            params.ExclusiveStartKey = (0, logs_1.stringToLastEvaluatedKey)(pageKey);
        }
        // Create QueryCommand
        const command = new client_dynamodb_1.QueryCommand(params);
        // TODO: Catch errors and throw QPQ ones
        const data = yield dynamoDBClient.send(command);
        return (0, itemsToQpqPagedData_1.itemsToQpqPagedData)((((_a = data.Items) === null || _a === void 0 ? void 0 : _a.map((i) => (0, convertObjectToDynamoMap_1.convertDynamoMapToObject)(i))) || []), data.LastEvaluatedKey);
    });
}
exports.query = query;
