import { EventActionType, actionResult, ErrorTypeEnum, } from 'quidproquo-core';
const ErrorTypeHttpResponseMap = {
    [ErrorTypeEnum.BadRequest]: 400,
    [ErrorTypeEnum.Unauthorized]: 401,
    [ErrorTypeEnum.PaymentRequired]: 402,
    [ErrorTypeEnum.Forbidden]: 403,
    [ErrorTypeEnum.NotFound]: 404,
    [ErrorTypeEnum.TimeOut]: 408,
    [ErrorTypeEnum.Conflict]: 409,
    [ErrorTypeEnum.UnsupportedMediaType]: 415,
    [ErrorTypeEnum.OutOfResources]: 500,
    [ErrorTypeEnum.GenericError]: 500,
    [ErrorTypeEnum.NotImplemented]: 501,
    [ErrorTypeEnum.NoContent]: 204,
    [ErrorTypeEnum.Invalid]: 422,
};
const transformHttpEventHeadersToAPIGatewayProxyResultHeaders = (headers) => {
    return Object.keys(headers)
        .filter((header) => !!headers[header])
        .reduce((acc, header) => ({ ...acc, [header]: headers[header] }), {});
};
const getResponseFromErrorResult = (error) => {
    const statusCode = ErrorTypeHttpResponseMap[error.errorType] || 500;
    return {
        status: statusCode,
        body: JSON.stringify({
            errorType: error.errorType,
            errorText: error.errorText,
        }),
        fallbackToCDN: true,
    };
};
const getProcessTransformResponseResult = (qpqConfig) => {
    // We might need to JSON.stringify the body.
    return async ({ eventParams, qpqEventRecordResponses }) => {
        const [cloudFrontRequestEvent] = eventParams;
        const [seoEventResponse] = qpqEventRecordResponses;
        // If we have an error, we need to transform it to a response, otherwise we can just use the record as is
        const successRecord = seoEventResponse.success ? seoEventResponse.result : getResponseFromErrorResult(seoEventResponse.error);
        if (successRecord.fallbackToCDN) {
            return actionResult(cloudFrontRequestEvent.Records[0].cf.request);
        }
        const headers = successRecord.headers || {};
        const responseHeaders = Object.keys(headers).reduce((acc, header) => ({ ...acc, [header]: [{ value: headers[header] }] }), {});
        const result = {
            status: `${successRecord.status}`,
            statusDescription: 'OK',
            body: successRecord.body,
            headers: responseHeaders,
            // TODO: Revist this.
            bodyEncoding: successRecord.bodyEncoding === 'base64' ? 'base64' : 'text',
        };
        return actionResult(result);
    };
};
export const getEventTransformResponseResultActionProcessor = async (qpqConfig) => ({
    [EventActionType.TransformResponseResult]: getProcessTransformResponseResult(qpqConfig),
});
