import { qpqCoreUtils, actionResultError, ErrorTypeEnum } from 'quidproquo-core';
import { getKvsDynamoTableNameFromConfig } from '../../../awsNamingUtils';
import { actionResult, KeyValueStoreActionType } from 'quidproquo-core';
import { query } from '../../../logic/dynamo';
import { getDynamoTableIndexByConfigAndQuery } from '../../../logic/dynamo/qpqDynamoOrm';
const getProcessKeyValueStoreQuery = (qpqConfig) => {
    return async ({ keyValueStoreName, keyCondition, options }) => {
        const dynamoTableName = getKvsDynamoTableNameFromConfig(keyValueStoreName, qpqConfig, 'kvs');
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const storeConfig = qpqCoreUtils.getKeyValueStoreByName(qpqConfig, keyValueStoreName);
        if (!storeConfig) {
            return actionResultError(ErrorTypeEnum.NotFound, `Could not find key value store with name "${keyValueStoreName}"`);
        }
        const items = await query(dynamoTableName, region, keyCondition, options?.filter, options?.nextPageKey, getDynamoTableIndexByConfigAndQuery(storeConfig, keyCondition), options?.limit, options?.sortAscending);
        return actionResult(items);
    };
};
export const getKeyValueStoreQueryActionProcessor = async (qpqConfig) => ({
    [KeyValueStoreActionType.Query]: getProcessKeyValueStoreQuery(qpqConfig),
});
