import { SystemActionType, createRuntime, actionResultError, ErrorTypeEnum, actionResult, QpqRuntimeType, qpqCoreUtils, } from 'quidproquo-core';
import { randomGuid } from '../../../awsLambdaUtils';
export const getDateNow = () => new Date().toISOString();
const getProcessExecuteStory = (qpqConfig) => {
    const moduleName = qpqCoreUtils.getApplicationModuleName(qpqConfig);
    return async (payload, session, actionProcessors, logger, updateSession, dynamicModuleLoader) => {
        console.log('Trying to load module');
        let story = await dynamicModuleLoader(payload.runtime);
        console.log('After - Trying to load module');
        if (!story) {
            console.log('No story');
            return actionResultError(ErrorTypeEnum.NotFound, `Unable to dynamically load: [${payload.runtime}]`);
        }
        const resolveStory = createRuntime(qpqConfig, {
            context: payload.storySession?.context || session.context,
            depth: (payload.storySession?.depth || session.depth || 0) + 1,
            accessToken: payload.storySession?.accessToken || session.accessToken,
            correlation: payload.storySession?.correlation || session.correlation,
        }, async () => actionProcessors, getDateNow, logger, 
        // TODO: Share this logic.
        `${moduleName}::${randomGuid()}`, QpqRuntimeType.EXECUTE_STORY, dynamicModuleLoader, [payload.runtime]);
        const storyResult = await resolveStory(story, payload.params);
        if (storyResult.error) {
            return actionResultError(storyResult.error.errorType, storyResult.error.errorText, storyResult.error.errorStack ? `${payload.runtime} -> [${storyResult.error.errorStack}]` : payload.runtime);
        }
        return actionResult(storyResult.result);
    };
};
export const getSystemExecuteStoryActionProcessor = async (qpqConfig) => ({
    [SystemActionType.ExecuteStory]: getProcessExecuteStory(qpqConfig),
});
