import { actionResult, qpqCoreUtils, UserDirectoryActionType, actionResultError, ErrorTypeEnum, } from 'quidproquo-core';
import { getCFExportNameUserPoolIdFromConfig } from '../../../awsNamingUtils';
import { getExportedValue } from '../../../logic/cloudformation/getExportedValue';
import { decodeValidJwt } from '../../../logic/cognito/decodeValidJwt';
const getProcessDecodeAccessToken = (qpqConfig) => {
    return async ({ userDirectoryName, accessToken, ignoreExpiration }) => {
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const userPoolId = await getExportedValue(getCFExportNameUserPoolIdFromConfig(userDirectoryName, qpqConfig), region);
        const authInfo = await decodeValidJwt(userPoolId, region, ignoreExpiration, accessToken);
        if (!authInfo || !authInfo?.username) {
            return actionResultError(ErrorTypeEnum.Unauthorized, 'Invalid accessToken');
        }
        return actionResult({
            userId: authInfo.userId,
            username: authInfo.username,
        });
    };
};
export const getUserDirectoryDecodeAccessTokenActionProcessor = async (qpqConfig) => ({
    [UserDirectoryActionType.DecodeAccessToken]: getProcessDecodeAccessToken(qpqConfig),
});
