import { actionResult, qpqCoreUtils, UserDirectoryActionType, actionResultError, UserDirectoryGetUserAttributesErrorTypeEnum, actionResultErrorFromCaughtError, } from 'quidproquo-core';
import { getCFExportNameUserPoolIdFromConfig } from '../../../awsNamingUtils';
import { getExportedValue } from '../../../logic/cloudformation/getExportedValue';
import { getUserAttributes } from '../../../logic/cognito/getUserAttributes';
const getProcessGetUserAttributes = (qpqConfig) => {
    return async ({ userDirectoryName, username }) => {
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const userPoolId = await getExportedValue(getCFExportNameUserPoolIdFromConfig(userDirectoryName, qpqConfig), region);
        try {
            const userAttributes = await getUserAttributes(userPoolId, region, username);
            return actionResult(userAttributes);
        }
        catch (error) {
            return actionResultErrorFromCaughtError(error, {
                UserNotFoundException: () => actionResultError(UserDirectoryGetUserAttributesErrorTypeEnum.UserNotFound, 'User not found'),
            });
        }
    };
};
export const getUserDirectoryGetUserAttributesActionProcessor = async (qpqConfig) => ({
    [UserDirectoryActionType.GetUserAttributes]: getProcessGetUserAttributes(qpqConfig),
});
