const apiGatewayEventHandler_redirect = async (event, context) => {
    console.log('event: ', JSON.stringify(event, null, 2));
    console.log('process.env: ', JSON.stringify(process.env, null, 2));
    const redirectConfig = JSON.parse(process.env.redirectConfig);
    // For direct urls ~ Go straight to the url
    let redirectUrl = redirectConfig.redirectUrl;
    // Otherwise it must be a domain redirect
    if (!redirectConfig.redirectUrl.startsWith('http')) {
        const environment = JSON.parse(process.env.environment);
        const featureEnvironment = JSON.parse(process.env.featureEnvironment || '""');
        let baseDomain = redirectConfig.redirectUrl;
        if (redirectConfig.addEnvironment && environment !== 'production') {
            baseDomain = `${environment}.${baseDomain}`;
        }
        if (redirectConfig.addFeatureEnvironment && featureEnvironment) {
            baseDomain = `${featureEnvironment}.${baseDomain}`;
        }
        redirectUrl = `https://${baseDomain}${event.path}`;
    }
    // Add query parameters if they exist
    const queryParams = event.queryStringParameters;
    if (queryParams) {
        const queryString = Object.entries(queryParams)
            .filter(([, value]) => value !== undefined) // Filter out undefined values
            .map(([key, value]) => `${encodeURIComponent(key)}=${encodeURIComponent(value)}`)
            .join('&');
        redirectUrl += `?${queryString}`;
    }
    return {
        statusCode: 301,
        body: '',
        headers: {
            Location: redirectUrl,
        },
    };
};
export const getApiGatewayEventHandler_redirect = () => apiGatewayEventHandler_redirect;
