import NodeCache from 'node-cache';
const cache = new WeakMap();
/**
 * Memoizes a function by caching its return values.
 * @param func The function to memoize.
 * @param ttlInSeconds Time-to-live for the cached values in seconds.
 * @returns The memoized function.
 */
export const memoFuncAsync = (func, ttlInSeconds = 3600) => {
    return (async (...args) => {
        if (!cache.has(func)) {
            cache.set(func, new NodeCache({ stdTTL: ttlInSeconds }));
        }
        const cacheKey = JSON.stringify(args);
        const nodeCache = cache.get(func);
        if (nodeCache.has(cacheKey)) {
            return nodeCache.get(cacheKey);
        }
        try {
            // Await the result and then cache it
            const result = await func(...args);
            nodeCache.set(cacheKey, result);
            return result;
        }
        catch (err) {
            throw err; // re-throw the error to be caught by caller
        }
    });
};
