import { CognitoIdentityProviderClient, AdminCreateUserCommand, DeliveryMediumType, MessageActionType, } from '@aws-sdk/client-cognito-identity-provider';
import { authenticateUser } from './authenticateUser';
import { setUserPassword } from './setUserPassword';
import { getCognitoUserAttributesFromQpqUserAttributes } from './cognitoAttributeMap';
import { createAwsClient } from '../createAwsClient';
export const createUser = async (userPoolId, region, clientId, createUserRequest) => {
    const cognitoClient = createAwsClient(CognitoIdentityProviderClient, { region });
    const params = {
        UserPoolId: userPoolId,
        Username: createUserRequest.email,
        MessageAction: MessageActionType.SUPPRESS,
        DesiredDeliveryMediums: [DeliveryMediumType.EMAIL],
        UserAttributes: getCognitoUserAttributesFromQpqUserAttributes(createUserRequest),
        ForceAliasCreation: false,
    };
    if (createUserRequest.phoneNumber) {
        params.DesiredDeliveryMediums.push(DeliveryMediumType.SMS);
    }
    const response = await cognitoClient.send(new AdminCreateUserCommand(params));
    const username = response.User?.Username || '';
    // Set the user's password
    await setUserPassword(region, userPoolId, username, createUserRequest.password);
    // Authenticate the user
    const authResponse = await authenticateUser(userPoolId, clientId, region, false, username, createUserRequest.password);
    return authResponse;
};
