import { verify, decode } from 'jsonwebtoken';
import jwksClient from 'jwks-rsa';
export const decodeValidJwt = async (userPoolId, region, ignoreExpiration, accessToken) => {
    if (!accessToken) {
        return null;
    }
    try {
        const decodedToken = decode(accessToken, { complete: true });
        if (!decodedToken) {
            return null;
        }
        const client = jwksClient({
            jwksUri: `https://cognito-idp.${region}.amazonaws.com/${userPoolId}/.well-known/jwks.json`,
        });
        const key = await client.getSigningKey(decodedToken.header.kid);
        const signingKey = key.getPublicKey();
        const payload = verify(accessToken, signingKey, {
            algorithms: ['RS256'],
            ignoreExpiration,
        });
        return {
            userId: payload.sub,
            username: payload.username,
        };
    }
    catch (e) {
        console.log('Failed to decode jwt token', e);
        return null;
    }
};
