import { CognitoIdentityProviderClient, ForgotPasswordCommand, } from '@aws-sdk/client-cognito-identity-provider';
import { calculateSecretHash } from './utils/calculateSecretHash';
import { getUserPoolClientSecret } from './getUserPoolClientSecret';
import { createAwsClient } from '../createAwsClient';
export const forgotPassword = async (userPoolId, clientId, region, username) => {
    const cognitoClient = createAwsClient(CognitoIdentityProviderClient, { region });
    const clientSecret = await getUserPoolClientSecret(userPoolId, clientId, region);
    const secretHash = calculateSecretHash(username, clientId, clientSecret);
    const params = {
        ClientId: clientId,
        Username: username,
        SecretHash: secretHash,
        ClientMetadata: {
            userInitiated: 'true',
        },
    };
    const response = await cognitoClient.send(new ForgotPasswordCommand(params));
    const deliveryInfo = {
        attributeName: response.CodeDeliveryDetails.AttributeName || 'email',
        destination: response.CodeDeliveryDetails.Destination || 'unknown@email.com',
        deliveryMedium: response.CodeDeliveryDetails.DeliveryMedium || 'EMAIL',
    };
    return deliveryInfo;
};
