import { CognitoIdentityProviderClient, ListUsersCommand } from '@aws-sdk/client-cognito-identity-provider';
import { getQpqAttributesFromCognitoUserAttributes } from './cognitoAttributeMap';
import { pageKeyToPaginationToken, paginationTokenToPageKey } from './utils';
import { createAwsClient } from '../createAwsClient';
export const listPagedUsersByAttribute = async (userPoolId, region, attributeName, attributeValue, limit, pageKey) => {
    const cognitoClient = createAwsClient(CognitoIdentityProviderClient, { region });
    const response = await cognitoClient.send(new ListUsersCommand({
        UserPoolId: userPoolId,
        Limit: limit,
        Filter: `${attributeName} = "${attributeValue}"`,
        PaginationToken: pageKeyToPaginationToken(pageKey),
    }));
    const users = (response.Users || []).map((user) => {
        const validAttributes = (user.Attributes || []).filter((attr) => attr.Name && attr.Value);
        return getQpqAttributesFromCognitoUserAttributes(validAttributes);
    });
    return {
        nextPageKey: paginationTokenToPageKey(response.PaginationToken),
        items: users,
    };
};
