import { CognitoIdentityProviderClient, RespondToAuthChallengeCommand, } from '@aws-sdk/client-cognito-identity-provider';
import { calculateSecretHash } from './utils/calculateSecretHash';
import { getUserPoolClientSecret } from './getUserPoolClientSecret';
import { cognitoAdminInitiateAuthResponseToQpqAuthenticationInfo } from './utils/transformCognitoResponse';
import { createAwsClient } from '../createAwsClient';
export const respondToAuthChallengeChallenge = async (userPoolId, clientId, region, username, session, challengeNameType, attributes) => {
    const cognitoClient = createAwsClient(CognitoIdentityProviderClient, { region });
    const clientSecret = await getUserPoolClientSecret(userPoolId, clientId, region);
    const secretHash = calculateSecretHash(username, clientId, clientSecret);
    const params = {
        ChallengeName: challengeNameType,
        ClientId: clientId,
        Session: session,
        ChallengeResponses: {
            USERNAME: username,
            SECRET_HASH: secretHash,
            ...attributes,
        },
    };
    const issueDateTime = new Date().toISOString();
    const response = await cognitoClient.send(new RespondToAuthChallengeCommand(params));
    // transform the response into your custom format, similar to your refreshToken function
    return cognitoAdminInitiateAuthResponseToQpqAuthenticationInfo(response, issueDateTime);
};
