import { AuthenticateUserChallenge } from 'quidproquo-core';
import { ChallengeNameType } from '@aws-sdk/client-cognito-identity-provider';
export const cognitoAuthenticationResultTypeToQpqAuthenticationInfo = (authResult, issueDateTime) => {
    // Parse the issueDateTime and add the expiresIn to get the expiration date
    let issueDate = new Date(issueDateTime);
    issueDate.setSeconds(issueDate.getSeconds() + (authResult.ExpiresIn || 0));
    const expiresAt = issueDate.toISOString();
    return {
        accessToken: authResult.AccessToken,
        idToken: authResult.IdToken,
        refreshToken: authResult.RefreshToken,
        tokenType: authResult.TokenType,
        expirationDurationInSeconds: authResult.ExpiresIn,
        expiresAt,
    };
};
export const cognitoChallengeNameTypeToQpqAuthenticateUserChallenge = (cognitoChallengeName) => {
    if (!cognitoChallengeName) {
        return AuthenticateUserChallenge.NONE;
    }
    const map = {
        [ChallengeNameType.NEW_PASSWORD_REQUIRED]: AuthenticateUserChallenge.NEW_PASSWORD_REQUIRED,
        [ChallengeNameType.CUSTOM_CHALLENGE]: AuthenticateUserChallenge.CUSTOM_CHALLENGE,
    };
    // TODO: handle the NOT-IMP cases
    const challenge = map[cognitoChallengeName] || `QPQ-NOT-IMP-${cognitoChallengeName}`;
    return challenge;
};
export const cognitoAdminInitiateAuthResponseToQpqAuthenticationInfo = (authResponse, issueDateTime) => {
    console.log('authResponse XYZ', authResponse);
    const res = {
        session: authResponse.Session,
        challenge: cognitoChallengeNameTypeToQpqAuthenticateUserChallenge(authResponse.ChallengeName),
        challengeParameters: authResponse.ChallengeParameters,
    };
    if (authResponse.AuthenticationResult) {
        res.authenticationInfo = cognitoAuthenticationResultTypeToQpqAuthenticationInfo(authResponse.AuthenticationResult, issueDateTime);
    }
    return res;
};
