import { DynamoDBClient, ScanCommand } from '@aws-sdk/client-dynamodb';
import { convertDynamoMapToObject } from './convertObjectToDynamoMap';
import { stringToLastEvaluatedKey } from './logs';
import { itemsToQpqPagedData } from './utils/itemsToQpqPagedData';
import { buildExpressionAttributeValues, buildExpressionAttributeNames, buildDynamoQueryExpression, } from './qpqDynamoOrm';
import { createAwsClient } from '../createAwsClient';
export async function scan(tableName, region, filterExpression, pageKey) {
    // Instantiate DynamoDB client
    const dynamoDBClient = createAwsClient(DynamoDBClient, { region });
    const params = {
        TableName: tableName,
        FilterExpression: buildDynamoQueryExpression(filterExpression),
        ExpressionAttributeValues: filterExpression && buildExpressionAttributeValues([filterExpression]),
        ExpressionAttributeNames: filterExpression && buildExpressionAttributeNames([filterExpression]),
    };
    if (pageKey) {
        params.ExclusiveStartKey = stringToLastEvaluatedKey(pageKey);
    }
    // Create ScanCommand
    const command = new ScanCommand(params);
    // TODO: Catch errors and throw QPQ ones
    const data = await dynamoDBClient.send(command);
    return itemsToQpqPagedData((data.Items?.map((i) => convertDynamoMapToObject(i)) || []), data.LastEvaluatedKey);
}
